.. include:: ../../README.rst 

For more detailed examples refer to the :doc:`examples` page.

.. toctree::
   :maxdepth: 5
   :hidden:

   examples 
   core
   internals
   development 
   license 

